Changelog
=========

0.2 (2014-02-02)
----------------

- Install theming.toolkit.views.


0.1 (2014-02-01)
----------------

- Install required products.
- Customise settings for Plone site and add-ons.
